@@ -1,7 +1,10 @@
 begin
   require 'escape_utils'
 rescue LoadError
-  # Loading EscapeUtils failed
+  begin
+    require 'cgi/escape'
+  rescue LoadError
+  end
 end
 
 module Temple
@@ -26,6 +29,14 @@ module Temple
       def escape_html(html)
         EscapeUtils.escape_html(html.to_s, false)
       end
+    elsif defined?(CGI.escapeHTML)
+      # Returns an escaped copy of `html`.
+      #
+      # @param html [String] The string to escape
+      # @return [String] The escaped string
+      def escape_html(html)
+        CGI.escapeHTML(html.to_s)
+      end
     else
       # Used by escape_html
       # @api private
@@ -54,7 +65,7 @@ module Temple
     # @return [String] Variable name
     def unique_name(prefix = nil)
       @unique_name ||= 0
-      prefix ||= (@unique_prefix ||= self.class.name.gsub('::', '_').downcase)
+      prefix ||= (@unique_prefix ||= self.class.name.gsub('::'.freeze, '_'.freeze).downcase)
       "_#{prefix}#{@unique_name += 1}"
     end
 
@@ -81,8 +92,8 @@ module Temple
       level = text.scan(/^\s*/).map(&:size).min
       text = text.gsub(/(?!\A)^\s{#{level}}/, '') if level > 0
 
-      text = text.sub(/\A\s*\n?/, "\n") if indent_next
-      text = text.gsub("\n", indent)
+      text = text.sub(/\A\s*\n?/, "\n".freeze) if indent_next
+      text = text.gsub("\n".freeze, indent)
 
       safe ? text.html_safe : text
     end
