@@ -2,7 +2,7 @@ require 'helper'
 
 describe Temple::Filters::Eraser do
   it 'should respect keep' do
-    eraser = Temple::Filters::Eraser.new(:keep => [:a])
+    eraser = Temple::Filters::Eraser.new(keep: [:a])
     eraser.call([:multi,
       [:a],
       [:b],
@@ -15,7 +15,7 @@ describe Temple::Filters::Eraser do
   end
 
   it 'should respect erase' do
-    eraser = Temple::Filters::Eraser.new(:erase => [:a])
+    eraser = Temple::Filters::Eraser.new(erase: [:a])
     eraser.call([:multi,
       [:a],
       [:b],
@@ -28,7 +28,7 @@ describe Temple::Filters::Eraser do
   end
 
   it 'should choose erase over keep' do
-    eraser = Temple::Filters::Eraser.new(:keep => [:a, :b], :erase => [:a])
+    eraser = Temple::Filters::Eraser.new(keep: [:a, :b], erase: [:a])
     eraser.call([:multi,
       [:a],
       [:b],
@@ -41,7 +41,7 @@ describe Temple::Filters::Eraser do
   end
 
   it 'should erase nested types' do
-    eraser = Temple::Filters::Eraser.new(:erase => [[:a, :b]])
+    eraser = Temple::Filters::Eraser.new(erase: [[:a, :b]])
     eraser.call([:multi,
       [:a, :a],
       [:a, :b],
